/*
 *  Copyright (c) 2024 John Ahlroos
 *
 *  Creative Commons Attribution-NoDerivatives 4.0 International Public License
 *
 *  By exercising the Licensed Rights (defined below), You accept and agree
 *  to be bound by the terms and conditions of this Creative Commons
 *  Attribution-NoDerivatives 4.0 International Public License ("Public
 *  License"). To the extent this Public License may be interpreted as a
 *  contract, You are granted the Licensed Rights in consideration of Your
 *  acceptance of these terms and conditions, and the Licensor grants You
 *  such rights in consideration of benefits the Licensor receives from
 *  making the Licensed Material available under these terms and
 *  conditions.
 *
 *  Refer to LICENSE file or https://creativecommons.org/licenses/by-nd/4.0 for full license.
 *
 */
package com.devsoap.json;

import org.junit.jupiter.api.Test;

import static com.devsoap.json.JsonAssert.assertThat;

public class ArrayTraversalAssertionTest {

    private static final String JSON = """
    [{
        "array": [
          { "item": 1 },
          { "item": 2 }
        ],
    
        "numericArray": [
            1,2,3
        ],
    
        "fieldArray": {
          "array": [
             { "item": 3 },
             { "item": 4 }
          ],
          "numericArray": [
            1,2,3
          ]
        },
    
        "matrix": [
          [1,2],
          [3,4]
        ]
    }]
    """;

    @Test
    public void rootFieldArray() {
        assertThat(JSON)
                .asArray()
                .first()
                .array("array")
                .first()
                .field("item")
                .isEqualTo(1);

        assertThat(JSON)
                .asArray()
                .first()
                .array("array")
                .last()
                .field("item")
                .isEqualTo(2);
    }

    @Test
    public void fieldArray() {
        assertThat(JSON)
                .asArray()
                .first()
                .field("fieldArray")
                .array("array")
                .first()
                .field("item")
                .isEqualTo(3);

        assertThat(JSON)
                .asArray()
                .first()
                .field("fieldArray")
                .array("array")
                .last()
                .field("item")
                .isEqualTo(4);
    }

    @Test
    public void numericArray() {
        assertThat(JSON)
                .asArray()
                .first()
                .array("numericArray", Integer.class)
                .first()
                .isEqualTo(1);

        assertThat(JSON)
                .asArray()
                .first()
                .field("fieldArray")
                .array("numericArray", Integer.class)
                .first()
                .isEqualTo(1);

        assertThat("[1,2,3]")
                .asArray(Integer.class)
                .last()
                .isEqualTo(3);
    }

    @Test
    public void matrix() {
        assertThat(JSON)
                .asArray()
                .first()
                .array("matrix")
                .first()
                .asArray()
                .first()
                .asInteger()
                .isEqualTo(1);

        assertThat(JSON)
                .asArray()
                .first()
                .array("matrix")
                .first()
                .asArray()
                .last()
                .asInteger()
                .isEqualTo(2);

        assertThat(JSON)
                .asArray()
                .first()
                .array("matrix")
                .last()
                .asArray()
                .first()
                .asInteger()
                .isEqualTo(3);

        assertThat(JSON)
                .asArray()
                .first()
                .array("matrix")
                .last()
                .asArray()
                .last()
                .asInteger()
                .isEqualTo(4);
    }
}